@@ -1,5 +1,8 @@
+# -*- encoding: utf-8 -*-
 #
-# Copyright 2013 Intel
+# Copyright © 2013 Intel
+#
+# Author: Shuangtai Tian <shuangtai.tian@intel.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,10 +16,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import cfg
-import oslo_messaging
+from oslo.config import cfg
 
-from ceilometer.agent import plugin_base
+from ceilometer import plugin
 
 
 OPTS = [
@@ -29,13 +31,15 @@ OPTS = [
 cfg.CONF.register_opts(OPTS)
 
 
-class ComputeNotificationBase(plugin_base.NotificationBase):
-    def get_targets(self, conf):
-        """Return a sequence of oslo_messaging.Target
-
-        This sequence is defining the exchange and topics to be connected for
-        this plugin.
+class ComputeNotificationBase(plugin.NotificationBase):
+    @staticmethod
+    def get_exchange_topics(conf):
+        """Return a sequence of ExchangeTopics defining the exchange and
+        topics to be connected for this plugin.
         """
-        return [oslo_messaging.Target(topic=topic,
-                                      exchange=conf.nova_control_exchange)
-                for topic in self.get_notification_topics(conf)]
+        return [
+            plugin.ExchangeTopics(
+                exchange=conf.nova_control_exchange,
+                topics=set(topic + ".info"
+                           for topic in conf.notification_topics)),
+        ]
