@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Cloudbase Solutions Srl
 #
 # Author: Claudiu Belu <cbelu@cloudbasesolutions.com>
@@ -30,7 +28,7 @@ if sys.platform == 'win32':
 from oslo.config import cfg
 
 from ceilometer.compute.virt import inspector
-from ceilometer.openstack.common.gettextutils import _
+from ceilometer.openstack.common.gettextutils import _  # noqa
 from ceilometer.openstack.common import log as logging
 
 CONF = cfg.CONF
@@ -48,14 +46,15 @@ class UtilsV2(object):
     _PROC_SETTING = 'Msvm_ProcessorSettingData'
     _SYNTH_ETH_PORT = 'Msvm_SyntheticEthernetPortSettingData'
     _ETH_PORT_ALLOC = 'Msvm_EthernetPortAllocationSettingData'
+    _PORT_ACL_SET_DATA = 'Msvm_EthernetSwitchPortAclSettingData'
     _STORAGE_ALLOC = 'Msvm_StorageAllocationSettingData'
     _VS_SETTING_DATA = 'Msvm_VirtualSystemSettingData'
-    _AGGREG_METRIC = 'Msvm_AggregationMetricDefinition'
     _METRICS_ME = 'Msvm_MetricForME'
+    _BASE_METRICS_VALUE = 'Msvm_BaseMetricValue'
 
     _CPU_METRIC_NAME = 'Aggregated Average CPU Utilization'
-    _NET_IN_METRIC_NAME = 'Aggregated Filtered Incoming Network Traffic'
-    _NET_OUT_METRIC_NAME = 'Aggregated Filtered Outgoing Network Traffic'
+    _NET_IN_METRIC_NAME = 'Filtered Incoming Network Traffic'
+    _NET_OUT_METRIC_NAME = 'Filtered Outgoing Network Traffic'
     # Disk metrics are supported from Hyper-V 2012 R2
     _DISK_RD_METRIC_NAME = 'Disk Data Read'
     _DISK_WR_METRIC_NAME = 'Disk Data Written'
@@ -90,7 +89,11 @@ class UtilsV2(object):
         cpu_metrics_def = self._get_metric_def(self._CPU_METRIC_NAME)
         cpu_metric_aggr = self._get_metrics(vm, cpu_metrics_def)
 
-        return (long(cpu_metric_aggr[0].MetricValue) if cpu_metric_aggr else 0,
+        cpu_used = 0
+        if cpu_metric_aggr:
+            cpu_used = long(cpu_metric_aggr[0].MetricValue)
+
+        return (cpu_used,
                 int(cpu_sd.VirtualQuantity),
                 long(vm.OnTimeInMilliseconds))
 
@@ -104,12 +107,16 @@ class UtilsV2(object):
 
         for port in ports:
             vnic = [v for v in vnics if port.Parent == v.path_()][0]
-            metric_values = self._get_metric_values(
-                port, [metric_def_in, metric_def_out])
+
+            metric_value_instances = self._get_metric_value_instances(
+                port.associators(wmi_result_class=self._PORT_ACL_SET_DATA),
+                self._BASE_METRICS_VALUE)
+            metric_values = self._sum_metric_values_by_defs(
+                metric_value_instances, [metric_def_in, metric_def_out])
 
             yield {
-                'rx_bytes': metric_values[0],
-                'tx_bytes': metric_values[1],
+                'rx_mb': metric_values[0],
+                'tx_mb': metric_values[1],
                 'element_name': vnic.ElementName,
                 'address': vnic.Address
             }
@@ -142,10 +149,7 @@ class UtilsV2(object):
             tot_metric_val += long(metric.MetricValue)
         return tot_metric_val
 
-    def _get_metric_values(self, element, metric_defs):
-        element_metrics = element.associators(
-            wmi_association_class=self._METRICS_ME)
-
+    def _sum_metric_values_by_defs(self, element_metrics, metric_defs):
         metric_values = []
         for metric_def in metric_defs:
             if metric_def:
@@ -156,6 +160,20 @@ class UtilsV2(object):
                 metric_values.append(0)
         return metric_values
 
+    def _get_metric_value_instances(self, elements, result_class):
+        instances = []
+        for el in elements:
+            associators = el.associators(wmi_result_class=result_class)
+            if associators:
+                instances.append(associators[0])
+
+        return instances
+
+    def _get_metric_values(self, element, metric_defs):
+        element_metrics = element.associators(
+            wmi_association_class=self._METRICS_ME)
+        return self._sum_metric_values_by_defs(element_metrics, metric_defs)
+
     def _lookup_vm(self, vm_name):
         vms = self._conn.Msvm_ComputerSystem(ElementName=vm_name)
         n = len(vms)
