@@ -22,14 +22,15 @@
 
 from oslo.config import cfg
 
-from ceilometer import sample
+from ceilometer.openstack.common.gettextutils import _  # noqa
 from ceilometer.openstack.common import log
 from ceilometer import plugin
+from ceilometer import sample
 
 OPTS = [
     cfg.StrOpt('neutron_control_exchange',
                default='neutron',
-               help="Exchange name for Neutron notifications",
+               help="Exchange name for Neutron notifications.",
                deprecated_name='quantum_control_exchange'),
 ]
 
@@ -75,7 +76,7 @@ class NetworkNotificationBase(plugin.NotificationBase):
         ]
 
     def process_notification(self, message):
-        LOG.info('network notification %r', message)
+        LOG.info(_('network notification %r') % message)
         message['payload'] = message['payload'][self.resource_name]
         counter_name = getattr(self, 'counter_name', self.resource_name)
         unit_value = getattr(self, 'unit', self.resource_name)
@@ -86,7 +87,7 @@ class NetworkNotificationBase(plugin.NotificationBase):
             unit=unit_value,
             volume=1,
             user_id=message['_context_user_id'],
-            project_id=message['payload']['tenant_id'],
+            project_id=message['_context_tenant_id'],
             resource_id=message['payload']['id'],
             message=message)
 
@@ -99,7 +100,7 @@ class NetworkNotificationBase(plugin.NotificationBase):
                 unit=unit_value,
                 volume=1,
                 user_id=message['_context_user_id'],
-                project_id=message['payload']['tenant_id'],
+                project_id=message['_context_tenant_id'],
                 resource_id=message['payload']['id'],
                 message=message)
 
