@@ -15,79 +15,69 @@
 
 import abc
 
-from oslo_utils import netutils
+import six
+from six.moves.urllib import parse as url_parse
 from stevedore import driver as _driver
-from urllib import parse as urlparse
 
-from ceilometer.polling import plugin_base
+from ceilometer.central import plugin
+from ceilometer.openstack.common import network_utils
 from ceilometer import sample
 
 
-class _Base(plugin_base.PollsterBase, metaclass=abc.ABCMeta):
+@six.add_metaclass(abc.ABCMeta)
+class _Base(plugin.CentralPollster):
 
     NAMESPACE = 'network.statistics.drivers'
     drivers = {}
 
-    @property
-    def default_discovery(self):
-        # this signifies that the pollster gets its resources from
-        # elsewhere, in this case they're manually listed in the
-        # pipeline configuration
-        return None
-
-    @property
-    @abc.abstractmethod
+    @abc.abstractproperty
     def meter_name(self):
-        """Return a Meter Name."""
+        '''Return a Meter Name.'''
 
-    @property
-    @abc.abstractmethod
+    @abc.abstractproperty
     def meter_type(self):
-        """Return a Meter Type."""
+        '''Return a Meter Type.'''
 
-    @property
-    @abc.abstractmethod
+    @abc.abstractproperty
     def meter_unit(self):
-        """Return a Meter Unit."""
+        '''Return a Meter Unit.'''
 
     @staticmethod
     def _parse_my_resource(resource):
 
-        parse_url = netutils.urlsplit(resource)
+        parse_url = network_utils.urlsplit(resource)
 
-        params = urlparse.parse_qs(parse_url.query)
-        parts = urlparse.ParseResult(parse_url.scheme,
-                                     parse_url.netloc,
-                                     parse_url.path,
-                                     None,
-                                     None,
-                                     None)
+        params = url_parse.parse_qs(parse_url.query)
+        parts = url_parse.ParseResult(parse_url.scheme,
+                                      parse_url.netloc,
+                                      parse_url.path,
+                                      None,
+                                      None,
+                                      None)
         return parts, params
 
     @staticmethod
-    def get_driver(conf, scheme):
+    def get_driver(scheme):
         if scheme not in _Base.drivers:
             _Base.drivers[scheme] = _driver.DriverManager(_Base.NAMESPACE,
-                                                          scheme).driver(conf)
+                                                          scheme).driver()
         return _Base.drivers[scheme]
 
-    def get_samples(self, manager, cache, resources):
-        resources = resources or []
+    def get_samples(self, manager, cache, resources=[]):
         for resource in resources:
             parse_url, params = self._parse_my_resource(resource)
-            ext = self.get_driver(self.conf, parse_url.scheme)
+            ext = self.get_driver(parse_url.scheme)
             sample_data = ext.get_sample_data(self.meter_name,
                                               parse_url,
                                               params,
                                               cache)
-
-            for data in sample_data or []:
+            for data in sample_data:
                 if data is None:
                     continue
                 if not isinstance(data, list):
                     data = [data]
                 for (volume, resource_id,
-                     resource_metadata, project_id) in data:
+                     resource_metadata, timestamp) in data:
 
                     yield sample.Sample(
                         name=self.meter_name,
@@ -95,7 +85,8 @@ class _Base(plugin_base.PollsterBase, metaclass=abc.ABCMeta):
                         unit=self.meter_unit,
                         volume=volume,
                         user_id=None,
-                        project_id=project_id,
+                        project_id=None,
                         resource_id=resource_id,
+                        timestamp=timestamp,
                         resource_metadata=resource_metadata
                     )
