@@ -19,7 +19,10 @@
 # under the License.
 
 import abc
+
+import six
 from stevedore import driver
+
 from ceilometer.openstack.common import network_utils
 
 
@@ -34,11 +37,10 @@ def get_publisher(url, namespace='ceilometer.publisher'):
     return loaded_driver.driver(parse_result)
 
 
+@six.add_metaclass(abc.ABCMeta)
 class PublisherBase(object):
     """Base class for plugins that publish the sampler."""
 
-    __metaclass__ = abc.ABCMeta
-
     def __init__(self, parsed_url):
         pass
 
