@@ -1,5 +1,8 @@
+# -*- encoding: utf-8 -*-
 #
-# Copyright 2013 eNovance
+# Copyright © 2013 eNovance
+#
+# Author: Julien Danjou <julien@danjou.info>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -18,27 +21,18 @@
 from ceilometer import publisher
 
 
-class TestPublisher(publisher.ConfigPublisherBase):
+class TestPublisher(publisher.PublisherBase):
     """Publisher used in unit testing."""
 
-    def __init__(self, conf, parsed_url):
-        super().__init__(conf, parsed_url)
+    def __init__(self, parsed_url):
         self.samples = []
-        self.events = []
         self.calls = 0
 
-    def publish_samples(self, samples):
+    def publish_samples(self, context, samples):
         """Send a metering message for publishing
 
+        :param context: Execution context from the service or RPC call
         :param samples: Samples from pipeline after transformation
         """
         self.samples.extend(samples)
         self.calls += 1
-
-    def publish_events(self, events):
-        """Send an event message for publishing
-
-        :param events: events from pipeline after transformation
-        """
-        self.events.extend(events)
-        self.calls += 1
