@@ -1,6 +1,10 @@
+# -*- encoding: utf-8 -*-
 #
-# Copyright 2013 eNovance <licensing@enovance.com>
-# Copyright 2013 Red Hat, Inc.
+# Copyright © 2013 eNovance <licensing@enovance.com>
+# Copyright © 2013 Red Hat, Inc.
+#
+# Author: Mehdi Abaakouk <mehdi.abaakouk@enovance.com>
+#         Angus Salkeld <asalkeld@redhat.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -44,3 +48,9 @@ def upgrade(migrate_engine):
         mysql_engine='InnoDB',
         mysql_charset='utf8')
     alarm.create()
+
+
+def downgrade(migrate_engine):
+    meta = MetaData(bind=migrate_engine)
+    alarm = Table('alarm', meta, autoload=True)
+    alarm.drop()
