@@ -1,3 +1,4 @@
+# -*- encoding: utf-8 -*-
 #
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -16,7 +17,7 @@ from sqlalchemy import Index, MetaData, Table
 
 
 INDEXES = {
-    # `table_name`: ((`index_name`, `column`),)
+    #`table_name`: ((`index_name`, `column`),)
     "user": (('ix_user_id', 'id'),),
     "source": (('ix_source_id', 'id'),),
     "project": (('ix_project_id', 'id'),),
@@ -35,3 +36,14 @@ def upgrade(migrate_engine):
         for index_name, column in indexes:
             index = Index(index_name, table.c[column])
             index.drop()
+
+
+def downgrade(migrate_engine):
+    meta = MetaData(bind=migrate_engine)
+    load_tables = dict((table_name, Table(table_name, meta, autoload=True))
+                       for table_name in INDEXES.keys())
+    for table_name, indexes in INDEXES.items():
+        table = load_tables[table_name]
+        for index_name, column in indexes:
+            index = Index(index_name, table.c[column])
+            index.create()
