@@ -15,6 +15,7 @@
 
 from migrate import ForeignKeyConstraint
 from sqlalchemy import MetaData, Table
+from sqlalchemy.sql.expression import select
 
 TABLES = ['resource', 'sourceassoc', 'user',
           'project', 'meter', 'source', 'alarm']
@@ -36,6 +37,8 @@ INDEXES = {
 
 
 def upgrade(migrate_engine):
+    if migrate_engine.name == 'sqlite':
+        return
     meta = MetaData(bind=migrate_engine)
     load_tables = dict((table_name, Table(table_name, meta, autoload=True))
                        for table_name in TABLES)
@@ -43,6 +46,11 @@ def upgrade(migrate_engine):
         table = load_tables[table_name]
         for column, ref_table_name, ref_column_name in indexes:
             ref_table = load_tables[ref_table_name]
+            subq = select([getattr(ref_table.c, ref_column_name)])
+            sql_del = table.delete().where(
+                ~ getattr(table.c, column).in_(subq))
+            migrate_engine.execute(sql_del)
+
             params = {'columns': [table.c[column]],
                       'refcolumns': [ref_table.c[ref_column_name]]}
             if migrate_engine.name == 'mysql':
@@ -52,6 +60,8 @@ def upgrade(migrate_engine):
 
 
 def downgrade(migrate_engine):
+    if migrate_engine.name == 'sqlite':
+        return
     meta = MetaData(bind=migrate_engine)
     load_tables = dict((table_name, Table(table_name, meta, autoload=True))
                        for table_name in TABLES)
@@ -63,5 +73,6 @@ def downgrade(migrate_engine):
                       'refcolumns': [ref_table.c[ref_column_name]]}
             if migrate_engine.name == 'mysql':
                 params['name'] = "_".join(('fk', table_name, column))
-            fkey = ForeignKeyConstraint(**params)
-            fkey.drop()
+            with migrate_engine.begin():
+                fkey = ForeignKeyConstraint(**params)
+                fkey.drop()
