@@ -1,5 +1,8 @@
+# -*- encoding: utf-8 -*-
 #
-# Copyright 2013 eNovance <licensing@enovance.com>
+# Copyright © 2013 eNovance <licensing@enovance.com>
+#
+# Author: Julien Danjou <julien@danjou.info>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -21,3 +24,10 @@ def upgrade(migrate_engine):
     meta.bind = migrate_engine
     alarm = Table('alarm', meta, autoload=True)
     alarm.c.counter_name.alter(name='meter_name')
+
+
+def downgrade(migrate_engine):
+    meta = MetaData()
+    meta.bind = migrate_engine
+    alarm = Table('alarm', meta, autoload=True)
+    alarm.c.meter_name.alter(name='counter_name')
