@@ -16,6 +16,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from __future__ import print_function
 
 import sys
 
@@ -26,7 +27,7 @@ from ceilometer import storage
 
 def show_users(db, args):
     for u in sorted(db.get_users()):
-        print u
+        print(u)
 
 
 def show_resources(db, args):
@@ -35,29 +36,26 @@ def show_resources(db, args):
     else:
         users = sorted(db.get_users())
     for u in users:
-        print u
+        print(u)
         for resource in db.get_resources(user=u):
-            print '  %(resource_id)s %(timestamp)s' % resource
+            print('  %(resource_id)s %(timestamp)s' % resource)
             for k, v in sorted(resource['metadata'].iteritems()):
-                print '      %-10s : %s' % (k, v)
+                print('      %-10s : %s' % (k, v))
             for meter in resource['meter']:
+                totals = db.get_statistics(storage.SampleFilter(
+                    user=u,
+                    meter=meter['counter_name'],
+                    resource=resource['resource_id'],
+                ))
                 # FIXME(dhellmann): Need a way to tell whether to use
                 # max() or sum() by meter name without hard-coding.
                 if meter['counter_name'] in ['cpu', 'disk']:
-                    totals = db.get_volume_max(storage.EventFilter(
-                            user=u,
-                            meter=meter['counter_name'],
-                            resource=resource['resource_id'],
-                            ))
+                    value = totals[0]['max']
                 else:
-                    totals = db.get_volume_sum(storage.EventFilter(
-                            user=u,
-                            meter=meter['counter_name'],
-                            resource=resource['resource_id'],
-                            ))
-                print '    %s (%s): %s' % \
-                    (meter['counter_name'], meter['counter_type'],
-                     totals.next()['value'])
+                    value = totals[0]['sum']
+                print('    %s (%s): %s' % \
+                     (meter['counter_name'], meter['counter_type'],
+                      value))
 
 
 def show_total_resources(db, args):
@@ -66,44 +64,41 @@ def show_total_resources(db, args):
     else:
         users = sorted(db.get_users())
     for u in users:
-        print u
+        print(u)
         for meter in ['disk', 'cpu', 'instance']:
+            stats = db.get_statistics(storage.SampleFilter(
+                user=u,
+                meter=meter,
+            ))
             if meter in ['cpu', 'disk']:
-                total = db.get_volume_max(storage.EventFilter(
-                        user=u,
-                        meter=meter,
-                        ))
+                total = stats['max']
             else:
-                total = db.get_volume_sum(storage.EventFilter(
-                        user=u,
-                        meter=meter,
-                        ))
-            for t in total:
-                print '  ', meter, t['resource_id'], t['value']
+                total = stats['sum']
+            print('  ', meter, total)
 
 
 def show_raw(db, args):
     fmt = '    %(timestamp)s %(counter_name)10s %(counter_volume)s'
     for u in sorted(db.get_users()):
-        print u
+        print(u)
         for resource in db.get_resources(user=u):
-            print '  ', resource['resource_id']
-            for event in db.get_samples(storage.EventFilter(
+            print('  ', resource['resource_id'])
+            for sample in db.get_samples(storage.SampleFilter(
                     user=u,
                     resource=resource['resource_id'],
-                    )):
-                print fmt % event
+            )):
+                print(fmt % sample)
 
 
 def show_help(db, args):
-    print 'COMMANDS:'
+    print('COMMANDS:')
     for name in sorted(COMMANDS.keys()):
-        print name
+        print(name)
 
 
 def show_projects(db, args):
     for u in sorted(db.get_projects()):
-        print u
+        print(u)
 
 
 COMMANDS = {
@@ -113,7 +108,7 @@ COMMANDS = {
     'resources': show_resources,
     'total_resources': show_total_resources,
     'raw': show_raw,
-    }
+}
 
 
 def main(argv):
@@ -122,8 +117,7 @@ def main(argv):
         # NOTE(dhellmann): Read the configuration file(s) for the
         #ceilometer collector by default.
         default_config_files=['/etc/ceilometer/ceilometer.conf'],
-        )
-    storage.register_opts(cfg.CONF)
+    )
     db = storage.get_connection(cfg.CONF)
     command = extra_args[0] if extra_args else 'help'
     COMMANDS[command](db, extra_args[1:])
